package org.ananas.mac.menu;

/*
 * Copyright 2003, Benoit Marchal. All rights reserved.
 * Distributed under the artistic license (open source).
 * See www.ananas.org for licensing information.
 */

import java.util.ResourceBundle;

/**
 * <p>This class provides a set of methods to create "application-smart" menu
 * items.</p>
 * <p>An "application-smart" menu item is a menu item that will appear in
 * in the application menu under MacOS. It will be managed as a regular
 * menu under other OS.</p>
 * <p>You can force the use of regular menu items by setting the
 * <tt>org.ananas.mac.menu.forcePortable</tt> system property to <tt>true</tt>.
 * This is useful for testing on MacOS that the menu behaves as expected
 * on other platforms.</p>
 * <p>You can launch the application in this testing mode with the <tt>-D</tt>
 * command line option, as demonstrated below:</p><hr>
 * <pre>java -Dorg.ananas.mac.menu.forcePortable=true -jar menu.jar</pre><hr>
 *
 * @author <a href="http://www.marchal.com">Beno&icirc;t Marchal</a>
 * @see org.ananas.mac.menu.ApplicationItem
 * @version 1.0
 */
public final class ApplicationItemFactory
{
   /**
    * Shared instance for the library resources.
    */
   static ResourceBundle resources = ResourceBundle.getBundle("org.ananas.mac.menu.StringResources");

   /**
    * Creates a new "application-smart" menu item for the quit menu.
    * @return the new menu item
    */
   public static ApplicationItem createQuitItem()
   {
      if(isMacOS())
         return new QuitItem();
      else
         return new JavaItem();
   }

   /**
    * Creates a new "application-smart" menu item for the about menu.
    * @return the new menu item
    */
   public static ApplicationItem createAboutItem()
   {
      if(isMacOS())
         return new AboutItem();
      else
         return new JavaItem();
   }

   /**
    * Creates a new "application-smart" menu item for the preferences menu.
    * @return the new menu item
    */
   public static ApplicationItem createPreferencesItem()
   {
      if(isMacOS())
         return new PreferencesItem();
      else
         return new JavaItem();
   }

   /**
    * Utility method: tests if we need MacOS-specific menu items.
    * @return false if we're not on MacOS or the system flag forces the
    *    portable classes (e.g. for testing), true otherwise
    */
   private static boolean isMacOS()
   {
      if(Boolean.getBoolean("org.ananas.mac.menu.forcePortable"))
         return false;
      else
         return System.getProperty("mrj.version") != null;
   }
}