package org.ananas.mac.menu.demo;

/*
 * Copyright 2003, Benoit Marchal. All rights reserved.
 * Distributed under the artistic license (open source).
 * See www.ananas.org for licensing information.
 */

import java.awt.*;
import java.awt.event.*;
import org.ananas.mac.menu.*;

/**
 * <p>This class demonstrates the use of the library to abstract application
 * menus. If you run this application on a Mac, it will use the application
 * menu but if you run it on another computer, it will use the regular
 * menu bar for those items that go in the application menu.</p>
 * <p>By the way, this application is no beauty-price, nor is it very
 * useful. It's only intended as a demonstration.</p>
 * <p><b>Tip</b> Do you want to test the cross-platform look on a Mac?
 * You can with the system property, as explained for
 * <tt>ApplicationItemFactory</tt>.</p>
 *
 * @author <a href="http://www.marchal.com">Beno&icirc;t Marchal</a>
 * @see org.ananas.mac.menu.ApplicationItemFactory
 * @version 1.0
 */

public class AWTDemo
   extends Frame
{
   /**
    * Prompt property. Whether to prompt the user before exiting,
    * it is controlled by the preference box.
    */
   private boolean prompt;
   
   /**
    * Just a label on the main window. It changes when the user
    * selects menus (not very useful but it gets a point across)...
    */
   private Label message;

   /**
    * The about dialog box. It helps demonstrate registering for the about
    * item in the application menu.
    */
   private class AboutDialog
      extends Dialog
   {
      /**
       * Creates a new AboutDialog.
       * @param owner parent frame
       */
      public AboutDialog(Frame owner)
      {
         super(owner,"About AWTDemo",true);
         setResizable(false);
         add(new Label("AWTDemo Demonstrates the use of the org.ananas.mac.menu package."),BorderLayout.NORTH);
         add(new Label("You can obtain the package from ananas.org/mac."),BorderLayout.CENTER);
         add(new Label("\u00a9 2003, Beno\u00eet Marchal. Distributed under the artistic license."),BorderLayout.SOUTH);
         addWindowListener(new WindowAdapter()
         {
            public void windowClosing(WindowEvent e)
            {
               dispose();
            }
         });
         pack();
      }
   }
   
   /**
    * The preference dialog. It helps demonstrates registering for the
    * preferences item in the application menu.
    */
   private class PreferencesDialog
      extends Dialog
   {
      /**
       * Control for the property.
       */
      private Checkbox checkbox;
   
      /**
       * Creates a new PreferencesDialog.
       * @param owner parent frame
       */
      public PreferencesDialog(Frame owner)
      {
         super(owner,"Preferences",true);
         setResizable(false);
         add(checkbox = new Checkbox("Prompt before closing",prompt));
         addWindowListener(new WindowAdapter()
         {
            public void windowClosing(WindowEvent e)
            {
               prompt = checkbox.getState();
               dispose();
            }
         });
         pack();
      }
   }
   
   /**
    * A message box. It helps demonstrates registering for the
    * quit item in the application menu.
    */
   private class PromptDialog
      extends Dialog
   {
      /**
       * the user choice (true if he clicked yes)
       */
      private boolean result;
      
      /**
       * Creates a new PromptDialog.
       * @param owner parent frame
       */
      public PromptDialog(Frame owner)
      {
         super(owner,"AWTDemo",true);
         setResizable(false);
         add(new Label("Do you really want to quit?"),BorderLayout.CENTER);
         Button yes = new Button("Yes"),
                no = new Button("No");
         Panel panel = new Panel();
         panel.add(yes);
         panel.add(no);
         add(panel,BorderLayout.SOUTH);
         yes.addActionListener(new ActionListener()
         {
            public void actionPerformed(ActionEvent e)
            {
               doYes();
            }
         });
         no.addActionListener(new ActionListener()
         {
            public void actionPerformed(ActionEvent e)
            {
               doNo();
            }
         });
         addWindowListener(new WindowAdapter()
         {
            public void windowClosing(WindowEvent e)
            {
               doNo();
            }
         });
         pack();
      }
      
      /**
       * Called when the user clicks "Yes."
       */
      private void doYes()
      {
         result = true;
         dispose();
      }
      
      /**
       * Called when the user clicks "No."
       */
      private void doNo()
      {
         result = false;
         dispose();
      }
      
      /**
       * Reports the user choice.
       * @return true if the user clicked yes, false otherwise
       */
      private boolean isYes()
      {
         return result;
      }
   }
   
   /**
    * <p>Creates a frame that demonstrates application menus. It will create
    * a regular menu as well as application-aware menus. You really want
    * to run this on a Mac platform and on another platform.</p>
    * <p>If you have Macs only, try VirtualPC or run it in forced mode.
    * If you have no Macs, <a href="http://www.apple.com/switch">switch</a>.</p>
    * <p>The following code runs the demo:</p><hr>
    * <pre>new AWTDemo().show();</pre><hr>
    * @see org.ananas.mac.menu.ApplicationItemFactory
    */
   public AWTDemo()
   {
      super("AWTDemo");
      // on MacOS X, the MRJ menus are only available after AWT has been initialized 
      // see http://developer.apple.com/techpubs/macosx/ReleaseNotes/java10.1.html#MRJToolkit
      pack();
      prompt = false;
      add(message = new Label("Choose a color..."),BorderLayout.CENTER);
      setSize(400,300);
      int keyModifier = Toolkit.getDefaultToolkit().getMenuShortcutKeyMask();
      Menu colorMenu = new Menu("Color"),
           helpMenu = new Menu("Help");
      MenuItem red = new MenuItem("Red",new MenuShortcut(KeyEvent.VK_R)),
               green = new MenuItem("Green",new MenuShortcut(KeyEvent.VK_G)),
               blue = new MenuItem("Blue",new MenuShortcut(KeyEvent.VK_B));
      ApplicationItem about = ApplicationItemFactory.createAboutItem(),
                      preferences = ApplicationItemFactory.createPreferencesItem(),
                      quit = ApplicationItemFactory.createQuitItem();
      colorMenu.add(red);
      colorMenu.add(green);
      colorMenu.add(blue);
      if(preferences.isAddedToMenu())
         colorMenu.addSeparator();
      preferences.register("Options...",colorMenu);
      if(quit.isAddedToMenu())
         colorMenu.addSeparator();
      quit.register("Exit",new MenuShortcut(KeyEvent.VK_X),colorMenu);
      about.register("About...",helpMenu);
      red.addActionListener(new ActionListener()
      {
         public void actionPerformed(ActionEvent e)
         {
            doRed();
         }
      });
      green.addActionListener(new ActionListener()
      {
         public void actionPerformed(ActionEvent e)
         {
            doGreen();
         }
      });
      blue.addActionListener(new ActionListener()
      {
         public void actionPerformed(ActionEvent e)
         {
            doBlue();
         }
      });
      about.addActionListener(new ActionListener()
      {
         public void actionPerformed(ActionEvent e)
         {
            doAbout();
         }
      });
      preferences.addActionListener(new ActionListener()
      {
         public void actionPerformed(ActionEvent e)
         {
            doPreferences();
         }
      });
      quit.addActionListener(new ActionListener()
      {
         public void actionPerformed(ActionEvent e)
         {
            doQuit();
         }
      });
      MenuBar menuBar = new MenuBar();
      menuBar.add(colorMenu);
      if(about.isAddedToMenu())
         menuBar.add(helpMenu);
      setMenuBar(menuBar);
      addWindowListener(new WindowAdapter()
      {
         public void windowClosing(WindowEvent e)
         {
            doQuit();
         }
      });
   }
   
   /**
    * Reacts to the user selecting the red menu item.
    */
   private void doRed()
   {
      message.setText("You choose red.");
      message.setForeground(Color.red);
   }

   /**
    * Reacts to the user selecting the green menu item.
    */
   private void doGreen()
   {
      message.setText("You choose green.");
      message.setForeground(Color.green);
   }

   /**
    * Reacts to the user selecting the blue menu item.
    */
   private void doBlue()
   {
      message.setText("You choose blue.");
      message.setForeground(Color.blue);
   }
   
   /**
    * Reacts to the user selecting the about
    * "application-smart" menu item.
    */
   private void doAbout()
   {
      new AboutDialog(this).show();
   }
   
   /**
    * Reacts to the user selecting the preferences
    * "application-smart" menu item.
    */
   private void doPreferences()
   {
      new PreferencesDialog(this).show();
   }
   
   /**
    * Reacts to the user selecting the quit
    * "application-smart" menu item.
    */
   private void doQuit()
   {
      if(prompt)
      {
         PromptDialog dlg = new PromptDialog(this);
         dlg.show();
         if(!dlg.isYes())
            return;
      }
      System.exit(0);
   }
   
   /**
    * Runs the demo. Opens the main frame on screen.
    */
   public static final void main(String[] params)
   {
      new AWTDemo().show();
   }
}